#ifndef SAA1064_H
#define	SAA1064_H
//------------------------------------------------------------------------------
#include <string.h>
#include "SAA1064_prototypes.h"
//------------------------------------------------------------------------------
void SAA1064_init()
{     
    I2C_init(100000);            //100 Khz
   
    I2C_start();
    
    I2C_write(SAA1064_ADDRESS);   
    I2C_write(CONTROL_REG);    
    I2C_write(DEVICE_CONFIG);    
    
    I2C_stop();
    
}
//------------------------------------------------------------------------------
void SAA1064_displayNum(signed int number)
{
    char* text = toString(number);
    
    I2C_start();
    
    I2C_write(SAA1064_ADDRESS); //Device address
    I2C_write(DISPLAY_REG);     //Display data start address. Auto increments on every write.
    SAA1064_write(text);
    
    I2C_stop();
}
//------------------------------------------------------------------------------
void SAA1064_write(char text[])
{
    text = get_lastCharAddr(text);
    
    char pos = 0;
    while(*text)
    {
       SAA1064_char(*text--, pos++);   //write data backwards 
    }
}
//------------------------------------------------------------------------------
void SAA1064_char(char asciiChar, char pos)
{    
    char digit = getDigit(asciiChar, pos); //ascii to 7 seg

    I2C_write(digit);                     
}
//------------------------------------------------------------------------------
char getDigit(char asciiChar, char pos) 
{
    char digit = 0;
    
    if(asciiChar >= '0' && asciiChar <= '9')
    {
        char i = asciiChar - '0';
        digit = (pos == 1) ? (digits[i] + DECIMAL_POINT) : digits[i]; //ANDing with DECIMAL_POINT Turns off MSB
    }
    else
        if(asciiChar == '-')
        {
            digit = (pos == 1) ? (digits[0] + DECIMAL_POINT) : 0x40;  //0x40 - minus symbol
        }
        else
            if(asciiChar == ' ')
            {
                digit = (pos == 1) ? (digits[0] + DECIMAL_POINT) : 0x00; //0x00 - blank. used for leading zero suppression
            }
    
    return digit;
}
//------------------------------------------------------------------------------
char* toString(signed int number)
{
  char strNum[10];
  sprintf(strNum,"%4i",number);
  
  return strNum;
}
//------------------------------------------------------------------------------
char* get_lastCharAddr(char text[])
{
  char lastAddr =  strlen(text) - 1;  
  
  return text + lastAddr;
}
//------------------------------------------------------------------------------
#endif	/* SAA1064_H */